.. image:: https://travis-ci.org/salah93/twitterbot.svg?branch=master
    :target: https://travis-ci.org/salah93/twitterbot

Twitter Bot
===================

# Translate Bot
An outline to get you started building your twitter bot

## Install
` pip install salahs-twitterbot `

## Twitter API
- create a new [twitter application](https://apps.twitter.com/)
- save consumer key, consumer secret, access  key and access secret as environment variables

```
export TWITTER_CONSUMER_KEY='aaaaaaaaaaaaaaaaaaaaaaaaa'
export TWITTER_CONSUMER_SECRET='aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa'
export TWITTER_ACCESS_TOKEN='aaaaaaaaaa-aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa'
export TWITTER_ACCESS_TOKEN_SECRET='aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa'
```
